summaryrefslogtreecommitdiff
path: root/gcc/lto
diff options
context:
space:
mode:
authorhubicka <hubicka@138bc75d-0d04-0410-961f-82ee72b054a4>2012-08-11 08:38:59 +0000
committerhubicka <hubicka@138bc75d-0d04-0410-961f-82ee72b054a4>2012-08-11 08:38:59 +0000
commit02b699d50d860e2554adddf09753492b6f4bda66 (patch)
tree0793ee7ca02faf63574b64bf05c816cc6b8837e1 /gcc/lto
parent97d653b923462b4bbe0d4458357b96acd0e936f5 (diff)
downloadgcc-02b699d50d860e2554adddf09753492b6f4bda66.tar.gz
* lto-cgraph.c (output_cgraph): Rename to ...
(output_symtab): ... this one. Update for LTO_section_symtab_nodes. (input_cgraph): Rename to ... (input_symtab): ... this one. Update for LTO_section_symtab_nodes. * lto-streamer-out.c (create_output_block): Do not set section_type. (produce_asm): Likewise. (lto_output_toplevel_asms): Likewise. (produce_asm_for_decls): Likewise. (lto_output): Use output_symtab. * lto-section-in.c (lto_section_name): Update. * lto-section-out.c (lto_destroy_simple_output_block): Remove section_type. * lto-streamer.h (enum lto_section_type): Remove LTO_section_varpool; rename LTO_section_cgraph to LTO_section_symtab_nodes. (struct lto_header): Remove section_type. * lto.c (read_cgraph_and_symbols): Use input_symtab. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@190312 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/lto')
-rw-r--r--gcc/lto/ChangeLog4
-rw-r--r--gcc/lto/lto.c4
2 files changed, 6 insertions, 2 deletions
diff --git a/gcc/lto/ChangeLog b/gcc/lto/ChangeLog
index c0ff256f3da..fb1ea42e25e 100644
--- a/gcc/lto/ChangeLog
+++ b/gcc/lto/ChangeLog
@@ -1,3 +1,7 @@
+2012-07-24 Jan Hubicka <jh@suse.cz>
+
+ * lto.c (read_cgraph_and_symbols): Use input_symtab.
+
2012-07-24 Uros Bizjak <ubizjak@gmail.com>
* lto-tree.h (lang_decl): Add variable_size GTY option.
diff --git a/gcc/lto/lto.c b/gcc/lto/lto.c
index 4f8c764b3f3..bd91c391fd1 100644
--- a/gcc/lto/lto.c
+++ b/gcc/lto/lto.c
@@ -1807,8 +1807,8 @@ read_cgraph_and_symbols (unsigned nfiles, const char **fnames)
fprintf (stderr, "\nReading the callgraph\n");
timevar_push (TV_IPA_LTO_CGRAPH_IO);
- /* Read the callgraph. */
- input_cgraph ();
+ /* Read the symtab. */
+ input_symtab ();
timevar_pop (TV_IPA_LTO_CGRAPH_IO);
if (!quiet_flag)